@@ -1,4 +1,4 @@
 state <- 'DE'
-cvap <- cvap_get(state)
+cvap <- cvap_get(state, year = 2019)
 data('de_block')
 data('de_block_group')
